from django.utils.safestring import mark_safe
from django.contrib.admin.widgets import FilteredSelectMultiple
from django import forms

class BetterFilterWidget(forms.SelectMultiple):
    class Media:
        extend = False
        css = {
            'all': ('css/better-filter-widget.css',)
        }
        js = ('js/better-filter-widget.js', )

    def render(self, name, value, attrs=None, choices=()):
        output = super(BetterFilterWidget, self).render(name, value, attrs, choices)
        output += u'''
        	<script type="text/javascript">
				(function($) {
                    $(window).ready(function(){
                        BetterFilterWidget('%s');
                    });
                })(window.$ || django.jQuery);
        	</script>
        ''' % name
        return mark_safe(output)


#!/usr/bin/env python

from setuptools import setup, find_packages

setup(
    name='django-better-filter-widget',
    version='0.4.2',
    author='Exotic Objects LLC',
    author_email='git@extc.co',
    license='MIT',
    url='https://github.com/ExoticObjects/django-better-filter-widget',
    include_package_data=True,
    long_description=open('README.md').read(),
    description='A better filter widget for foreign key relationships',
    packages=find_packages(),
)
